@@ -4,11 +4,11 @@ import fabtools.require
 
 from fabric.api import parallel
 from fabric.api import roles
-from fabric.api import task
+from farmboy.fabric_ import task
 
 
-@roles('web')
 @task
+@roles('web')
 @parallel
 def deploy():
     """Add tomcat to the <web> hosts."""
